# UIAutomatorViewer

#### 介绍
一个基于Python实现的UIAutomatorViewer,比Android原生的UIAutomatorViewer要稳定和方便一些。

#### 安装教程
```
pip install UIAutomatorViewer
```

#### 使用说明
命令行执行以下命令会自动在浏览器打开UIAutomatorViewer工具
```
$ uiautomatorviewer
```
